@@ -6,13 +6,19 @@ from typing import TypeVar
 import sentry_sdk
 from tornado.iostream import IOStream
 
-from cats import BytesAnyGen
 from cats.errors import ProtocolError
 from cats.identity import Identity
+from cats.types import BytesAnyGen
 from cats.v2 import C_NONE, Compressor
 from cats.v2.action import BaseAction, Input
 from cats.v2.config import Config
 
+try:
+    from uvloop.loop import TimerHandle as UVTimerHandle
+except ImportError:
+    class UVTimerHandle:
+        pass
+
 __all__ = [
     'ConnType',
     'Connection',
@@ -269,7 +275,7 @@ class Connection:
         for task in self._close_tasks():
             if task is None:
                 continue
-            if isinstance(task, asyncio.TimerHandle):
+            if isinstance(task, (asyncio.TimerHandle, UVTimerHandle)):
                 task.cancel()
             elif not task.done():
                 if exc and not isinstance(task, asyncio.Task):
